pyscard: smartcard library for python
=====================================

[pyscard](http://pyscard.sourceforge.net/) - python smart card library - is a python module adding smart
cards support to [python](https://www.python.org/).

![alt text](http://pyscard.sourceforge.net/_images/pyscard.jpg "pyscard architecture")

Documentation
-------------
http://pyscard.sourceforge.net/user-guide.html#pyscard-user-guide

Samples
-------
High level API samples: See http://pyscard.sourceforge.net/pyscard-framework.html#framework-samples
Low level API samples: See http://pyscard.sourceforge.net/pyscard-wrapper.html#wrapper-samples

Continuous Integration status
-----------------------------
Travis CI: [![Travis CI](https://travis-ci.org/LudovicRousseau/pyscard.svg "Travis CI")](https://travis-ci.org/LudovicRousseau/pyscard)

AppVeyor: [![Build status](https://ci.appveyor.com/api/projects/status/c97dsaodpcwkm0ra?svg=true)](https://ci.appveyor.com/project/LudovicRousseau/pyscard)

Coveralls: [![Coverage Status](https://coveralls.io/repos/LudovicRousseau/pyscard/badge.svg?branch=master&service=github)](https://coveralls.io/github/LudovicRousseau/pyscard?branch=master)
